@@ -1,12 +1,12 @@
 # models/polymorphic.py
 
 try:
-    from adjango.services.polymorphic import APolymorphicBaseService
+    from adjango.services.object.polymorphic import APolymorphicModelObjectBaseService
     from polymorphic.models import PolymorphicModel
     from adjango.managers.polymorphic import APolymorphicManager
 
 
-    class APolymorphicModel(PolymorphicModel, APolymorphicBaseService):
+    class APolymorphicModel(PolymorphicModel, APolymorphicModelObjectBaseService):
         objects = APolymorphicManager()
 
         class Meta:
