@@ -5,16 +5,17 @@ from typing import Type, Any
 
 from django.db.models import QuerySet
 
-from adjango.utils.funcs import aall, agetorn, afilter, aset, aadd
+from adjango.utils.funcs import aall, agetorn, getorn, afilter, aset, aadd
 
 
 class AQuerySet(QuerySet):
     async def aall(self): return await aall(self)
 
-    async def agetorn(
-            self, exception: Type[Exception] | None = None,
-            *args, **kwargs,
-    ) -> Any: return await agetorn(self, exception, *args, **kwargs)
+    def getorn(self, exception: Type[Exception] | None = None, *args, **kwargs) -> Any:
+        return getorn(self, exception, *args, **kwargs)
+
+    async def agetorn(self, exception: Type[Exception] | None = None, *args, **kwargs) -> Any:
+        return await agetorn(self, exception, *args, **kwargs)
 
     async def afilter(self, *args, **kwargs) -> list:
         return await afilter(self, *args, **kwargs)
