@@ -9,14 +9,18 @@ from django.core.mail import send_mail
 from django.template.loader import render_to_string
 
 
-def send_emails(subject: str, emails: tuple[str, ...] | list[str, ...], template: str, context=None):
+def send_emails(
+        subject: str,
+        emails: list[str, ...] | tuple[str, ...],
+        template: str, context=None
+) -> bool:
     """
     Отправляет email с использованием указанного шаблона.
 
-    @param subject: Тема письма.
-    @param emails: Список email-адресов получателей.
-    @param template: Путь к шаблону письма.
-    @param context: Контекст для рендеринга шаблона.
+    :param subject: Тема письма.
+    :param emails: Список email-адресов получателей.
+    :param template: Путь к шаблону письма.
+    :param context: Контекст для рендеринга шаблона.
     """
     from adjango.conf import ADJANGO_EMAIL_LOGGER_NAME
     log = logging.getLogger(ADJANGO_EMAIL_LOGGER_NAME)
@@ -27,5 +31,7 @@ def send_emails(subject: str, emails: tuple[str, ...] | list[str, ...], template
             html_message=render_to_string(template, context=context if context is not None else {})
     ):
         log.info(f'Successfully sent {template=} {emails=}')
+        return True
     else:
         log.critical(f'Failed to send {template=} {emails=} {context=}')
+        return False
